@@ -75,6 +75,10 @@ class PyJibe(QtWidgets.QMainWindow):
             print(__version__)
             QtWidgets.QApplication.processEvents()
             sys.exit(0)
+        self.show()
+        self.raise_()
+        self.activateWindow()
+        self.setWindowState(QtCore.Qt.WindowState.WindowActive)
 
     def add_subwindow(self, aclass, flist):
         """Add a subwindow, register data set and add to menu"""
@@ -195,7 +199,7 @@ class PyJibe(QtWidgets.QMainWindow):
     def load_data(self, files, retry_open=None, separate_analysis=False):
         # approach-retract data files
         supfiles = []
-        for ff in files:
+        for ff in sorted(files):
             path = pathlib.Path(ff)
             if path.suffix in registry.known_suffixes:
                 supfiles.append(ff)
